@@ -1222,6 +1222,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Hashtbl instead"]
 
+module In_channel = Stdlib.In_channel 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.In_channel instead"]
+
 module Int = Stdlib.Int 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1320,6 +1327,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Option instead"]
 
+module Out_channel = Stdlib.Out_channel 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Out_channel instead"]
+
 module Parsing = Stdlib.Parsing 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1452,17 +1466,3 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Weak instead"]
 
-module In_channel : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.In_channel instead"]
-
-module Out_channel : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Out_channel instead"]
-
